install.packages('wavelets')
library(wavelets)

install.packages('wmtsa')
library(wmtsa)

install.packages('waved')
library(waved)

install.packages('wavethresh')
library(wavetresh)

install.packages('WaveletComp')
library(WaveletComp)

# ----------------------------------------------------------
#  Practical Session 
# ----------------------------------------------------------

#2 Analysis of a univariate time series
#2.1 Example 1: a series with constant period  ----------------------
x = periodic.series(start.period = 50, length = 1000)
plot(x,type = 'l', main='Data x')
x = x + 0.2*rnorm(1000) # add some noise
plot(x,type = 'l', main='Data x')

my.data <- data.frame(x = x)

my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 128,
                        make.pval = TRUE, n.sim = 10)

wt.image(my.w, color.key = "quantile", n.levels = 250,
         legend.params = list(lab = "wavelet power levels", mar = 4.7)) #To plot the wavelet power spectrum



reconstruct(my.w, plot.waves = FALSE, lwd = c(1,2),
            legend.coords = "bottomleft", ylim = c(-1.8, 1.8))# it is obtained a denoised signal




#2.2 Example 2: a series with variable period ------------------------------
x = periodic.series(start.period = 20, end.period = 100, length = 1000)
x = x + 0.2*rnorm(1000)
plot(x,type = 'l') #A series with linearly increasing trend in frequency

my.data <- data.frame(x = x)
my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 128,
                        make.pval = TRUE, n.sim = 10)
?analyse.wavelet
my.w$Power
my.w$Power.pval
my.w$Power[my.w$Power.pval<0.05]
table(my.w$Power.pval<0.01)
table(my.w$Ridge==1) #1indicates the presence of a ridge in the “landscape” of power. The rigde is represented by a black line in the wavelet power spectrum.


wt.image(my.w, n.levels = 250,
         legend.params = list(lab = "wavelet power levels"))

my.rec <- reconstruct(my.w)
x.rec <- my.rec$series$x.r # x: name of original series

#2.3 Example 3: a series with two periods -----------------------------------
x1 <- periodic.series(start.period = 80, length = 1000)
x2 <- periodic.series(start.period = 30, length = 1000)
x <- x1 + x2 + 0.2*rnorm(1000)
plot(x,type = 'l')

my.data <- data.frame(x = x)
my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 128,
                        make.pval = TRUE, n.sim = 10)
wt.image(my.w, n.levels = 250,
         legend.params = list(lab = "wavelet power levels") )

#Reconstruction, using only period 80
reconstruct(my.w, sel.period = 80, plot.waves = TRUE, lwd = c(1,2),
            legend.coords = "bottomleft")

my.w$Period[(my.w$Period > 79) & (my.w$Period < 81)]


reconstruct(my.w, sel.period = c(30,80), plot.waves = TRUE, lwd = c(1,2),
            legend.coords = "bottomleft")

reconstruct(my.w, plot.waves = TRUE, lwd = c(1,2),
            legend.coords = "bottomleft")


# Comparation wih Fourier transform-------------------------------

x1 <- periodic.series(start.period = 20, length = 500)
plot(x1,type='l')
x2 <- periodic.series(start.period = 50, length = 500)
plot(x2,type='l')
x3 <- periodic.series(start.period = 150, length = 1000)
plot(x3,type='l')
x<-c(10*x1,10*x2,10*x3)
plot(x,type='l')

spectrum(x)
abline(v=1/20, col='red')
abline(v=1/50, col='red')
abline(v=1/150, col='red')


my.data <- data.frame(x = x)

my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 256,
                        make.pval = TRUE, n.sim = 10)

wt.image(my.w, color.key = "quantile", n.levels = 250,
         legend.params = list(lab = "wavelet power levels", mar = 4.7))


#Kepler data  -----------------------------------------------------------
datos <- read.table("/Users/alejandra/k9305831.dat", header = F)
head(datos)

x<-datos[,3]
plot(x,type='l')
my.data <- data.frame(x = x)
my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 128,
                        make.pval = TRUE, n.sim = 10)
wt.image(my.w, n.levels = 250,
         legend.params = list(lab = "wavelet power levels") )

#Reconstruction

reconstruct(my.w, plot.waves = TRUE, lwd = c(1,2),
            legend.coords = "bottomleft")

#  OGLE data  

datos <- read.table("/Users/alejandra/0phot.txt", header = F)
head(datos)

Mag<-datos[,2]
Mag[1:10]
plot(-Mag, type='l')
x<--Mag
my.data <- data.frame(x = x)

my.w <- analyze.wavelet(my.data, "x",
                        loess.span = 0,
                        dt = 1, dj = 1/250,
                        lowerPeriod = 16,
                        upperPeriod = 128,
                        make.pval = TRUE, n.sim = 10)

wt.image(my.w, color.key = "quantile", n.levels = 250,
         legend.params = list(lab = "wavelet power levels", mar = 4.7)) #To plot the wavelet power spectrum



reconstruct(my.w, plot.waves = FALSE, lwd = c(1,2), legend.coords = "bottomleft", ylim = c(-1.8, 1.8))# it is obtained a denoised signal



